summaryrefslogtreecommitdiff
path: root/src/mongo/db/clientcursor.h
diff options
context:
space:
mode:
authorliubov.molchanova <liubov.molchanova@mongodb.com>2023-05-17 08:16:48 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2023-05-17 10:20:42 +0000
commit87160f876c6fb94f5d03062b2caee57539ec5d8e (patch)
treeb78d9ca9e853a236e0a2f6432a6ac02dc50119cd /src/mongo/db/clientcursor.h
parent1c390a0c50104a04cbd8ecbefb99eaf22e1bc914 (diff)
downloadmongo-87160f876c6fb94f5d03062b2caee57539ec5d8e.tar.gz
Revert "SERVER-76427: Rename $telemetry to $queryStats"
This reverts commit d646e44b7801a3e5b3230bbae7dcfe05a5ed8707.
Diffstat (limited to 'src/mongo/db/clientcursor.h')
-rw-r--r--src/mongo/db/clientcursor.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/clientcursor.h b/src/mongo/db/clientcursor.h
index 8ae75473496..9e7d35ade9a 100644
--- a/src/mongo/db/clientcursor.h
+++ b/src/mongo/db/clientcursor.h
@@ -448,15 +448,15 @@ private:
boost::optional<uint32_t> _queryHash;
// If boost::none, telemetry should not be collected for this cursor.
- boost::optional<std::size_t> _queryStatsStoreKeyHash;
+ boost::optional<std::size_t> _telemetryStoreKeyHash;
// TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
- boost::optional<BSONObj> _queryStatsStoreKey;
+ boost::optional<BSONObj> _telemetryStoreKey;
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
// Useful for diagnostics like queryStats.
OpDebug::AdditiveMetrics _metrics;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry
// store key.
- std::unique_ptr<query_stats::RequestShapifier> _queryStatsRequestShapifier;
+ std::unique_ptr<telemetry::RequestShapifier> _telemetryRequestShapifier;
// Flag to decide if diagnostic information should be omitted.
bool _shouldOmitDiagnosticInformation{false};
@@ -598,7 +598,7 @@ void startClientCursorMonitor();
* Currently, telemetry is only collected for find and aggregate requests (and their subsequent
* getMore requests), so these should only be called from those request paths.
*/
-void collectQueryStatsMongod(OperationContext* opCtx, ClientCursorPin& cursor);
-void collectQueryStatsMongod(OperationContext* opCtx,
- std::unique_ptr<query_stats::RequestShapifier> requestShapifier);
+void collectTelemetryMongod(OperationContext* opCtx, ClientCursorPin& cursor);
+void collectTelemetryMongod(OperationContext* opCtx,
+ std::unique_ptr<telemetry::RequestShapifier> requestShapifier);
} // namespace mongo
@@ -448,15 +448,15 @@ private:
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
- // Useful for diagnostics like queryStats.
+ // Useful for diagnostics like telemetry.
OpDebug::AdditiveMetrics _metrics;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry